* Module 6

* Longitudinal Analysis Review: GA babies data
use "GAbabies.dta", clear

* Exploratory Data Analysis
twoway (scatter bweight birthord, jitter(10) mfcolor(none) mlcolor(midblue)) ///
       (lowess bweight birthord, lc(dknavy) lw(2)), legend(off) ///
       xscale(range(0.75 5.25)) xtitle("Birth order") ytitle("Birth weight (grams)")

graph box bweight, by(birthord, cols(5)) ytitle("Birth weight (grams)")

* Birth weight individual lines
xtline bweight if momid<=2383, i(momid) t(birthord) overlay legend(off) ///
     xlab(1(1)5) ylab(0(1000)5000) xtitle("Birth order") ytitle("Birth weight (grams)") ///
     addplot(lowess bweight birthord, lw(2))

* Fitted lines
regress bweight i.momid##c.birthord if momid<=2383
predict p
xtline p if momid<=2383, overlay t(birthord) i(momid) legend(off) xlab(1(1)5) ylab(0(1000)5000) ///
   xtitle("Birth order") ytitle("Birth weight (grams)") addplot(lowess bweight birthord, lw(2))



* GEE
* Declare the dataset to be "panel" data, grouped by momid
* with time variable birthord
xtset momid birthord

* Fit a linear model with independence correlation
xtgee bweight birthord initage, corr(ind) robust

* Fit a linear model with exchangeable correlation
xtgee bweight birthord initage, corr(exc) robust


* Mixed Models
* Declare the dataset to be "panel" data, grouped by momid
* with time variable birthord
xtset momid birthord

* Fit a linear model with random intercepts
xtmixed bweight birthord initage || momid:, reml

* Fit a linear model with random intercepts and slopes
xtmixed bweight birthord initage || momid: birthord, reml






* Case Study: Postnatal Depression
use "depress.dta", clear

* Exploratory Data Analysis
sort group
by group: summarize dep0 dep1 dep2 dep3 dep4 dep5 dep6

graph matrix dep0 dep1 dep2 dep3 dep4 dep5 dep6, half

sort group
by group: ttest dep0==dep6

corr dep0 dep1 dep2 dep3 dep4 dep5 dep6

gen diff=dep6-dep0
ttest diff, by(group) unequal

* change data to long form
reshape long dep, i(subj) j(visit)

xtline dep, i(subj) t(visit) overlay legend(off)
     xlab(0(1)6) xtitle("Visit") ytitle("Depression Score")

separate dep, by(group)
graph twoway (scatter dep0 visit, jitter(10) mcolor(green)) (scatter dep1 visit, jitter(10) mcolor(purple)) ///
     (lowess dep0 visit, lcolor(green)) (lowess dep1 visit, lcolor(purple)), ///
     xtitle(Visit) ytitle(Depression Score) ///
     legend(order(1 "Placebo" 2 "Estrogen"))

* GEE
xtset subj visit
xtgee dep visit i.group, corr(ind) robust
xtgee dep visit i.group if visit!=0, corr(ind) robust

xtgee dep visit i.group, corr(ar1) robust
estat wcorr

xtgee dep i.visit i.group, corr(ar1) robust
testparm i.visit

xtgee dep c.visit##i.group, corr(ar1) robust
lincom visit + 1.group#c.visit

xtgee dep visit c.visit#i.group, corr(ar1) robust

* Case Study: ICHS
* Exploratory data analysis

use ichs.dta, replace

list id age time infection xerop gender hfora cost sint

* Categorize by year of age
gen year=floor((age+36)/12)

* Cross-tabulate vitamin A deficiency and respiratory infection
bysort xerop: tab year infection


* Declare the dataset to be "panel" data, grouped by id
* with time variable time 
xtset id time

* Individual trajectories
xtline infection if id<121141, legend(off)
xtline xerop if id<121141, legend(off)

* Probabilities of infection and vitamin A deficiency
bysort xerop: summarize infection if time==1
bysort xerop: summarize infection if time==2
bysort xerop: summarize infection if time==3
bysort xerop: summarize infection if time==4
bysort xerop: summarize infection if time==5
bysort xerop: summarize infection if time==6

gen ageyear=floor((age+36)/12)
bysort xerop: summarize infection if year==0
bysort xerop: summarize infection if year==1
bysort xerop: summarize infection if year==2
bysort xerop: summarize infection if year==3
bysort xerop: summarize infection if year==4
bysort xerop: summarize infection if year==5
bysort xerop: summarize infection if year==6
bysort xerop: summarize infection if year==7

* Covariance and correlation
drop age gender year cost sint hfora
reshape wide infection xerop, i(id) j(time)
corr infection1 infection2 infection3 infection4 infection5 infection6
corr infection1 infection2 infection3 infection4 infection5 infection6, cov

* Generalized estimating equations

use ichs.dta, replace

* Declare the dataset to be "panel" data, grouped by id
* with time variable time
xtset id time

* Fit a GEE model with exchangeable working correlation
xtgee infection i.xerop age gender hfora cost sint, family(binomial) link(logit) corr(exch) robust
estat wcorr

* Generalized linear mixed-effects models

* Fit a model with random intercepts
help melogit
melogit infection i.xerop age i.gender hfora cost sint || id:

* Obtain predicted probabilities of infection, 
* setting the random effects to 0
margins i.xerop, predict(mu fixed)




* Case Study: Carpal Tunnel Syndrome
use "cts.dta", clear

*** generate baseline variable to be used when data are in long format
gen ctsaqfbase = ctsaqf0

***
*** some exploratory data analysis
***
  
summarize age
tab gender

tab idgroup 	
tab treatassign
tab treatassign surgical 
tab treatassign surgical if ctsaqf4!=.

bysort treatassign: summarize ctsaqf0 ctsaqf1 ctsaqf2 ctsaqf3 ctsaqf4 
bysort treatassign: cor ctsaqf0 ctsaqf1 ctsaqf2 ctsaqf3 ctsaqf4 

***
*** plot means by treatment group
***

*** change data from wide format to long format
reshape long surgreported ctsaqs ctsaqf, i(ID) j(visit)
save "cts_long.dta", replace



***
*** plot some individual series - one plot for treatassign=0 and one for treatassign==1
***

use "cts_long.dta", clear

graph twoway connected ctsaqf visit if (ID<=13062 & ID!=13009 & treatassign==0), /// 
	by(ID) mcolor(maroon) lcolor(maroon) xtitle("Visit") ytitle("CTSAQ-F") 
list ID surgical if (ID<=13062 & ID!=13009 & treatassign==0)

graph twoway connected ctsaqf visit if (ID<=13101 & ID!=13009 & treatassign==1), ///
	by(ID) mcolor(maroon) lcolor(maroon) xtitle("Visit") ytitle("CTSAQ-F")
list ID surgical if (ID<=13101 & ID!=13009 & treatassign==1)

***
*** plot some fitted lines
***

graph twoway (lfit ctsaqf visit) (scatter ctsaqf visit) ///
      if (ID<=13062 & ID!=13009 & treatassign==0), by(ID, legend(off)) ///
	  xtitle("Visit") ytitle("CTSAQ-F")

graph twoway (lfit ctsaqf visit) (scatter ctsaqf visit) ///
      if (ID<=13101 & ID!=13009 & treatassign==1), by(ID, legend(off)) ///
	  xtitle("Visit") ytitle("CTSAQ-F")


***
*** plot average outcome over time by treatment group
***


collapse (mean) ctsaqf, by(visit treatassign)

graph twoway (scatter ctsaqf visit if treatassign==0, msize(large) mfcolor(black)) (line ctsaqf visit if treatassign==0, lcolor(black) lpattern(solid)) ///
	(scatter ctsaqf visit if treatassign==1, msize(large)  mfcolor(white)) (line ctsaqf visit if treatassign==1, lcolor(black) lpattern(dash)), ///
	yscale(range(1 5)) ylabel(1(1)5) legend(order(2 "Non-surgery" 4 "Surgery")) xtitle("Visit") ytitle("Mean CTSAQ-F")


***
*** derive change scores
***

use "cts.dta", clear

gen change1 = ctsaqf1 - ctsaqf0 
gen change2 = ctsaqf2 - ctsaqf0 
gen change3 = ctsaqf3 - ctsaqf0 
gen change4 = ctsaqf4 - ctsaqf0 

***
*** [1] Analysis of post only
***
ttest ctsaqf1, by(treatassign) unequal   
ttest ctsaqf2, by(treatassign) unequal
ttest ctsaqf3, by(treatassign) unequal
ttest ctsaqf4, by(treatassign) unequal

***
*** [2] Analysis of change
***
ttest change1, by(treatassign) unequal    
ttest change2, by(treatassign) unequal    
ttest change3, by(treatassign) unequal    
ttest change4, by(treatassign) unequal    

***
*** [3] Analysis of post controlling for baseline
***
reg ctsaqf1 treatassign ctsaqf0
reg ctsaqf2 treatassign ctsaqf0
reg ctsaqf3 treatassign ctsaqf0
reg ctsaqf4 treatassign ctsaqf0

***
*** [4] Analysis of change controlling for baseline
***
reg change1 treatassign ctsaqf0
reg change2 treatassign ctsaqf0
reg change3 treatassign ctsaqf0
reg change4 treatassign ctsaqf0


***
*** PRIMARY ANALYSIS: post controlling for baseline, plus site
***
reg ctsaqf4 i.treatassign ctsaqf0 i.idgroup




**************************************************************
* longitudinal regression analysis - ITT				 *
**************************************************************

use "cts_long.dta", clear

*****
***** Generalized Estimating Equations
*****  

xtset ID visit

xtgee ctsaqf i.treatassign ctsaqfbase visit i.idgroup if visit!=0, corr(ind) robust

xtgee ctsaqf i.treatassign ctsaqfbase visit i.idgroup if visit!=0, corr(exc) robust
xtcorr

*****
***** Linear Mixed Models Analysis
*****  

*** Random Intercepts, all post time points in outcome vector, adjusted for baseline

xtmixed ctsaqf i.treatassign ctsaqfbase visit i.idgroup if visit!=0 || ID:, reml  

*** Random Intercepts + Slopes, all post time points in outcome vector, adjusted for baseline

xtmixed ctsaqf i.treatassign ctsaqfbase visit i.idgroup if visit!=0 || ID: visit, cov(unstruct) reml
 

 
**************************************************************
* as-treated analysis							 *
**************************************************************

*** generate as-treated surgery indicators
gen surgby3 = (surgical==1)
gen surgby6 = (surgical==1 | surgical==2)
gen surgby9 = (surgical==1 | surgical==2 | surgical==3)

save "cts_long.dta", replace

collapse (mean) surgby3 surgby6 surgby9 treatassign, by(ID)
tab treatassign surgby3, row
tab treatassign surgby6, row
tab treatassign surgby9, row

use "cts_long.dta", clear


collapse (mean) ctsaqf, by(visit surgby3)

graph twoway (scatter ctsaqf visit if surgby3==0, msize(large) mfcolor(black)) (line ctsaqf visit if surgby3==0, lcolor(black) lpattern(solid)) ///
	(scatter ctsaqf visit if surgby3==1, msize(large)  mfcolor(white)) (line ctsaqf visit if surgby3==1, lcolor(black) lpattern(dash)), ///
	yscale(range(1 5)) ylabel(1(1)5) legend(order(2 "Non-surgery" 4 "Surgery")) xtitle("Visit") ytitle("Mean CTSAQ-F")

use "cts_long.dta", clear

collapse (mean) ctsaqf, by(visit surgby9)

graph twoway (scatter ctsaqf visit if surgby9==0, msize(large) mfcolor(black)) (line ctsaqf visit if surgby9==0, lcolor(black) lpattern(solid)) ///
	(scatter ctsaqf visit if surgby9==1, msize(large)  mfcolor(white)) (line ctsaqf visit if surgby9==1, lcolor(black) lpattern(dash)), ///
	yscale(range(1 5)) ylabel(1(1)5) legend(order(2 "Non-surgery" 4 "Surgery")) xtitle("Visit") ytitle("Mean CTSAQ-F")



***
*** SECONDARY ANALYSIS: LMM controlling for baseline, site, visit
***
use "cts_long.dta", clear

xtset ID visit

xtmixed ctsaqf i.surgby3 ctsaqfbase visit i.idgroup if visit!=0 || ID:, reml
xtgee ctsaqf i.surgby3 ctsaqfbase visit i.idgroup if visit!=0, corr(ind) robust

xtmixed ctsaqf i.surgby9 ctsaqfbase visit i.idgroup if visit!=0 || ID:, reml  
xtgee ctsaqf i.surgby9 ctsaqfbase visit i.idgroup if visit!=0, corr(ind) robust
